==> dl.php?src=linea21_2_5_0.zip: linea21/languages/fr/lang_home.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['home']['name']="Accueil";
$lang['home']['comment']="%s derniers commentaires";
$lang['home']['comment_to_moderate']="%s commentaire(s) en attente de validation";
$lang['home']['workshop_pending_users']="groupes de travail : %s utilisateur(s) en attente";
$lang['home']['project']="Projets arrivant à échéance prochainement";
$lang['home']['my-projects']="Mes projets";
$lang['home']['project_task']="Projets : vos tâches à mettre en oeuvre";
$lang['home']['into_project']="pour le projet : ";
$lang['home']['latest_connected_users']="%s utilisateurs connectés les 15 dernières minutes";
$lang['home']['yp']="organisation(s) actuellement en préinscription";
$lang['home']['dashboard']="indicateur(s) à mettre à jour";
$lang['home']['user']="utilisateur(s) inscrit(s) depuis votre dernière connexion";
$lang['home']['news']="3 dernières actualités";
$lang['home']['publi']="dernières publications effectuées";
$lang['home']['report']="dernier rapport publié";
$lang['home']['accueil']="Bienvenue sur l'interface d'administration de Linea21 !";

$lang['home']['noresult']="Aucune donnée";
$lang['home']['noupdate']="Aucune donnée ne doit être mise à jour";
$lang['home']['help']=SITE_LINEA_NAME;
$lang['home']['help_list1']="Pour accéder à un module de gestion, cliquez sur son nom dans le menu gauche de l'application";
$lang['home']['help_list2']="Vous pouvez réaliser une recherche goblale à tout moment en utilisant le champ de saisie nommé \"recherche\"";
$lang['home']['help_list3']="Pour effectuer une recherche par module, cliquez sur recherche dans la barre de rubrique";
$lang['home']['help_list4']="la rubrique d'aide est spécifique à chaque module de gestion, n'hésitez pas à la consulter !";


?>

==> dl.php?src=linea21_2_8_0.zip: linea21/languages/fr/lang_home.utf-8.php <==
<?php
/**
 * @package linea21\languages\fr
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['home']['name']="Accueil";
$lang['home']['comment']="%s derniers commentaires";
$lang['home']['comment_to_moderate']="%s commentaire(s) en attente de validation";
$lang['home']['workshop_pending_users']="groupes de travail : %s utilisateur(s) en attente";
$lang['home']['project']="Projets arrivant à échéance prochainement";
$lang['home']['my-projects']="Mes projets";
$lang['home']['project_task']="Projets : vos tâches à mettre en oeuvre";
$lang['home']['into_project']="pour le projet : ";
$lang['home']['latest_connected_users']="%s utilisateurs connectés les 15 dernières minutes";
$lang['home']['yp']="organisation(s) actuellement en préinscription";
$lang['home']['dashboard']="indicateur(s) à mettre à jour";
$lang['home']['indicator-last-value']="dernière valeur renseignée le %s";
$lang['home']['indicator-delayed-msg']="retard estimé de %s jour(s)";
$lang['home']['indicator-next-entry']="prochaine saisie dans %s jour(s)";
$lang['home']['indicator-up-to-date']="à jour";
$lang['home']['indicator-delayed']="retard";
$lang['home']['user']="utilisateur(s) inscrit(s) depuis votre dernière connexion";
$lang['home']['news']="3 dernières actualités";
$lang['home']['publi']="dernières publications effectuées";
$lang['home']['report']="dernier rapport publié";
$lang['home']['accueil']="Bienvenue sur l'interface d'administration de Linea21 !";

$lang['home']['noresult']="Aucune donnée";
$lang['home']['noupdate']="Aucune donnée ne doit être mise à jour";
$lang['home']['help']=SITE_LINEA_NAME;
$lang['home']['help_list1']="Pour accéder à un module de gestion, cliquez sur son nom dans le menu gauche de l'application";
$lang['home']['help_list2']="Vous pouvez réaliser une recherche goblale à tout moment en utilisant le champ de saisie nommé \"recherche\"";
$lang['home']['help_list3']="Pour effectuer une recherche par module, cliquez sur recherche dans la barre de rubrique";
$lang['home']['help_list4']="la rubrique d'aide est spécifique à chaque module de gestion, n'hésitez pas à la consulter !";


?>
